@@ -73,8 +73,8 @@ def state_value(state, address, init = 0, end = 15):
     '''
     binary = format(state[address], '016b')
     r_init = len(binary)-1-init
-    r_end = len(binary)-1-end - 1 
-    kBitSubStr = binary[r_end : r_init]
+    r_end = len(binary)-1-end 
+    kBitSubStr = binary[r_end : r_init+1]
     return int(kBitSubStr, 2)
 
 def bit_value(state, address, bit):
@@ -92,15 +92,6 @@ def change_range_bit_value(state, address, init_bit, num_bit, value):
     temp2[idx:idx2] = temp
     return int("".join(temp2), 2)
 
-# def change_range_bit_value2(old_value, init_bit, num_bit, value):
-#     temp2 = list(old_value)
-#     idx = len(temp2)-init_bit-num_bit
-#     idx2 = len(temp2)-init_bit
-#     temp = list(format(value, '0'+str(num_bit)+ 'b'))
-#     temp2[idx:idx2] = temp
-#     return int("".join(temp2), 2)
-
-
 
 def change_bit_value(state, address, bit, value):
     if value:
